/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.springboot.springmvc.client;

import java.io.File;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.io.FileUtils;
import org.apache.servicecomb.demo.CategorizedTestCase;
import org.apache.servicecomb.demo.TestMgr;
import org.apache.servicecomb.provider.springmvc.reference.RestTemplateBuilder;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestOperations;

@Component
public class UploadDownloadSchemaTest implements CategorizedTestCase {
  RestOperations restOperations = RestTemplateBuilder.create();

  @Override
  public void testRestTransport() throws Exception {
    testEmptyFileUploadWork();
    testNonEmptyFileUploadWorkd();
  }

  private void testNonEmptyFileUploadWorkd() throws Exception {
    String file2Content = " bonjour";
    File someFile = File.createTempFile("upload2", ".txt");
    FileUtils.writeStringToFile(someFile, file2Content, StandardCharsets.UTF_8, false);
    HttpHeaders headers = new HttpHeaders();
    headers.setContentType(MediaType.MULTIPART_FORM_DATA);
    Map<String, Object> params = new HashMap<>();
    params.put("name", "test");
    params.put("file", someFile);
    HttpEntity<Map<String, Object>> entity = new HttpEntity<>(params, headers);
    String url = "servicecomb://springmvc/up/down/upload";
    String result = restOperations.postForObject(url, entity, String.class);
    TestMgr.check("test; bonjour", result);
  }

  private void testEmptyFileUploadWork() {
    HttpHeaders headers = new HttpHeaders();
    headers.setContentType(MediaType.MULTIPART_FORM_DATA);
    Map<String, Object> params = new HashMap<>();
    params.put("name", "test");
    HttpEntity<Map<String, Object>> entity = new HttpEntity<>(params, headers);
    String url = "servicecomb://springmvc/up/down/upload";
    String result = restOperations.postForObject(url, entity, String.class);
    TestMgr.check("test;", result);
  }
}
